@@ -8,6 +8,7 @@
 #' @param x Object with class "data.frame", "matrix" or "numeric"
 #' @param object object with class "EmissionsArray'
 #' @param ... ignored
+#' @importFrom  stats median quantile sd
 #' @rdname EmissionsArray
 #' @aliases EmissionsArray print.EmissionsArray summary.EmissionsArray
 #' plot.EmissionsArray
@@ -24,9 +25,8 @@
 #' veh <- data.frame(PC_G = PC_G)
 #' pc1 <- my_age(x = net$ldv, y = PC_G, name = "PC")
 #' pcw <- temp_fact(net$ldv+net$hdv, pc_profile)
-#' speed <- netspeed(pcw, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1,
-#' isList = T)
-#' pckm <- fkm[[1]](1:24); pckma <- cumsum(pckm)
+#' speed <- netspeed(pcw, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1)
+#' pckm <- units::set_units(fkm[[1]](1:24), "km"); pckma <- cumsum(pckm)
 #' cod1 <- emis_det(po = "CO", cc = 1000, eu = "III", km = pckma[1:11])
 #' cod2 <- emis_det(po = "CO", cc = 1000, eu = "I", km = pckma[12:24])
 #' #vehicles newer than pre-euro
@@ -35,7 +35,7 @@
 #' lef <- ef_ldv_scaled(co1, cod, v = "PC", cc = "<=1400",
 #'                      f = "G",p = "CO", eu=co1$Euro_LDV)
 #' E_CO <- emis(veh = pc1,lkm = net$lkm, ef = lef, speed = speed, agemax = 41,
-#'              profile = pc_profile, hour = 24, day = 7, array = T)
+#'              profile = pc_profile, simplify = TRUE)
 #' class(E_CO)
 #' summary(E_CO)
 #' E_CO
@@ -60,11 +60,16 @@ EmissionsArray <- function(x, ...) {
 #' @export
 print.EmissionsArray <- function(x,  ...) {
   e <- x
-if (is.array(e)) {
+  if (length(dim(e)) == 3) {
+    cat("This EmissionsArray has\n", dim(e)[1], "streets\n",
+        dim(e)[2], "vehicle categories\n", dim(e)[3], "hours\n")
+    print(utils::head(e))
+  } else {
     cat("This EmissionsArray has\n", dim(e)[1], "streets\n",
         dim(e)[2], "vehicle categories\n", dim(e)[3], "hours\n",
         dim(e)[4], "days\n")
     print(utils::head(e))
+
   }
 }
 
@@ -73,45 +78,48 @@ if (is.array(e)) {
 #' @export
 summary.EmissionsArray <- function(object, ...) {
   e <- object
+  mine <- round(min(e, na.rm = T), 3)
+  q1 <- round(stats::quantile(e, .25, na.rm = T), 3)
+  mede <- round(stats::median(e, na.rm = T), 3)
+  avge <- round(mean(e, na.rm = T), 3)
+  q3 <- round(stats::quantile(e, .75, na.rm = T), 3)
+  maxe <- round(max(e, na.rm = T), 3)
+  sde <- round(stats::sd(e, na.rm = T), 3)
+  a <- data.frame(Min = mine,
+                  `Qu.1` = q1,
+                  Median = mede,
+                  Mean = avge,
+                  `Qu.3` = q3,
+                  Max = maxe,
+                  sd = sde)
+  row.names(a) <- NULL
+  print(a)
+}
+  #' @rdname EmissionsArray
+  #' @method plot EmissionsArray
+  #' @export
+  plot.EmissionsArray <- function(x, ...) {
+    e <- x
     if (length(dim(e)) == 4 ) {
       df <- Emissions(t(apply(e, c(3, 4), sum, na.rm=T)))
-      names(df) <- unlist(lapply(1:ncol(df), function(i) paste0("h",i)))
-      # Total <- rowSums(df)
       Mean <- colMeans(df)
-      SD <- unlist(lapply(df, stats::sd, na.rm = T))
+      SD <- unlist(lapply(df, stats::sd))
       Min <- unlist(lapply(df, min))
       Max <- unlist(lapply(df, max))
       dfx <- data.frame(Mean, SD, Min, Max)
-      cat("Emissions\n")
-      return(dfx)
-    } else if (length(dim(e)) == 3 ){
-      #TODO: improve
-      apply(e, c(1, 3), sum, na.rm=T)
+      graphics::plot(y = dfx$Mean, x = 1:nrow(dfx),
+                     ylim = c(min(dfx$Min), max(dfx$Max)),
+                     col = "red", type = "l",
+                     main = "average emissions",
+                     ...)
+      graphics::lines(dfx$Mean+dfx$SD, ylim = c(min(dfx$Min), max(dfx$Max)))
+      graphics::lines(dfx$Mean-dfx$SD, ylim = c(min(dfx$Min), max(dfx$Max)))
+      graphics::points(dfx$Max, ylim = c(min(dfx$Min), max(dfx$Max)))
+      graphics::points(dfx$Min, ylim = c(min(dfx$Min), max(dfx$Max)))
+    } else {
+      df <- Emissions(apply(e, c(1, 3), mean, na.rm=T))
+      graphics::plot(df,
+                     main = "average emissions",
+                     ...)
     }
-}
-
-#' @rdname EmissionsArray
-#' @method plot EmissionsArray
-#' @export
-plot.EmissionsArray <- function(x, ...) {
-  e <- x
-  if (length(dim(e)) == 4 ) {
-    df <- Emissions(t(apply(e, c(3, 4), sum, na.rm=T)))
-  Mean <- colMeans(df)
-  SD <- unlist(lapply(df, stats::sd))
-  Min <- unlist(lapply(df, min))
-  Max <- unlist(lapply(df, max))
-  dfx <- data.frame(Mean, SD, Min, Max)
-  graphics::plot(y = dfx$Mean, x = 1:nrow(dfx),
-                 ylim = c(min(dfx$Min), max(dfx$Max)),
-                 col = "red", type = "l",
-                 ...)
-  graphics::lines(dfx$Mean+dfx$SD, ylim = c(min(dfx$Min), max(dfx$Max)))
-  graphics::lines(dfx$Mean-dfx$SD, ylim = c(min(dfx$Min), max(dfx$Max)))
-  graphics::points(dfx$Max, ylim = c(min(dfx$Min), max(dfx$Max)))
-  graphics::points(dfx$Min, ylim = c(min(dfx$Min), max(dfx$Max)))
-  } else {
-  df <- Emissions(apply(e, c(1, 3), sum, na.rm=T))
-  graphics::plot(df)
-}
-}
+  }
