@@ -8,7 +8,7 @@ netsf <- sf::st_as_sf(net)
 netsf$CO <- netsf$ldv*Emissions(1)
 netg <- emis_grid(spobj = netsf[, c("CO")], g = g, sr= 31983)
 
-
+# lines
 test_that("emis_grid works", {
   expect_equal(round(sum(emis_grid(spobj = netsf[, c("CO")],
                          g = g,
@@ -17,6 +17,7 @@ test_that("emis_grid works", {
 })
 
 
+# points
 sff2 <- suppressMessages(suppressWarnings(sf::st_centroid(netsf[, c("CO")])))
 test_that("emis_grid works", {
   expect_equal(round(sum(emis_grid(spobj = sff2,
@@ -25,9 +26,10 @@ test_that("emis_grid works", {
                round(as.numeric(0)))
 })
 
+# area - polygon
 test_that("emis_grid works", {
-  netp <- sf::st_sf(a = 1, geometry = sf::st_as_sfc(sf::st_bbox(sf::st_as_sf(net))))
-  netp$a <- Emissions(netp$a) # must include units otherwise does not work)
+  buf <- sf::st_buffer(sf::st_centroid(sf::st_as_sfc(sf::st_bbox(g))), dist = 0.01)
+  netp <- sf::st_sf(a = Emissions(1), geometry = buf)
   expect_equal(round(sum(emis_grid(spobj = netp,
                                    g = g,
                                    type = "polygon")$a[1], na.rm = T)),
@@ -53,8 +55,8 @@ test_that("emis_grid works", {
 })
 
 test_that("emis_grid works", {
-  netp <- sf::st_sf(a = 1, geometry = sf::st_as_sfc(sf::st_bbox(sf::st_as_sf(net))))
-  netp$a <- Emissions(netp$a) # must include units otherwise does not work)
+  buf <- sf::st_buffer(sf::st_centroid(sf::st_as_sfc(sf::st_bbox(g))), dist = 0.01)
+  netp <- sf::st_sf(a = Emissions(1), geometry = buf)
   expect_equal(round(sum(emis_grid(spobj = netp,
                                    g = g,
                                    type = "polygon",
